@@ -50,8 +50,15 @@ def testCJsonEncoder():
     str_ = json.dumps(data, ensure_ascii=False, cls=myutility.CJsonEncoder)
     print(str_)
 
+def test_get_dict_obj():
+    src = {'a': 1, 'b': 'c'}
+    dst = myutility.get_dict_obj(src)
+    for name, value in vars(dst).items():
+        print(f'name: {name}, value: {value}.')
+
 
 if __name__ == "__main__":
     # import sys;sys.argv = ['', 'Test.testName']
     #     unittest.main()
-    testCJsonEncoder()
+    # testCJsonEncoder()
+    test_get_dict_obj()
